@@ -8,25 +8,12 @@ try:
 except Exception as e:
     hasWx = False
     WX_VERSION = 0
-    print "EXCEPTION:", str(e)
 
 if hasWx:
     import wx.xrc
     from wx.lib.buttons import GenBitmapTextButton
-
-    #Imports depending on version:
-    if WX_VERSION == 2:
-        from wx.lib.pubsub import Publisher as pub
-
-    if WX_VERSION == 3:
-        from wx.lib.pubsub import pub
-        pub.subscribe
-
-    if WX_VERSION == 4:
-        from wx.lib.pubsub import pub
-        pub.subscribe
-        import wx.adv
-   
+    from pubsub import pub
+    import wx.adv
 
 import os
 import time
@@ -148,9 +135,15 @@ class ResamplingGUI(base.AnalysisGUI):
         mainSizer1.Add(normSizer, 1, wx.ALIGN_CENTER_HORIZONTAL|wx.EXPAND, 5 ) 
 
 
+
+
         resamplingSizer.Add( mainSizer1, 1, wx.EXPAND, 5 )
 
 
+
+
+
+
         # LOESS Check
         (self.wxobj.resamplingLoessCheck, loessCheckSizer) = self.defineCheckBox(resamplingPanel, labelText="Correct for Genome Positional Bias", widgetCheck=False, widgetSize=(-1,-1), tooltipText="Check to correct read-counts for possible regional biase using LOESS. Clicking on the button below will plot a preview, which is helpful to visualize the possible bias in the counts.")
         resamplingSizer.Add( loessCheckSizer, 0, wx.EXPAND, 5 )
@@ -187,6 +180,14 @@ class ResamplingGUI(base.AnalysisGUI):
 
         self.panel = resamplingPanel
 
+    def GlobalEnable(self):
+        self.wxobj.ctrlLibText.Enable()
+        self.wxobj.expLibText.Enable()
+
+    def GlobalDisable(self):
+        self.wxobj.ctrlLibText.Disable()
+        self.wxobj.expLibText.Disable()
+
 
 
 ########## CLASS #######################
@@ -211,7 +212,10 @@ class ResamplingMethod(base.DualConditionMethod):
                 LOESS=False,
                 ignoreCodon=True,
                 NTerminus=0.0,
-                CTerminus=0.0, wxobj=None):
+                CTerminus=0.0, 
+                ctrl_lib_str="",
+                exp_lib_str="", # should add Z
+                wxobj=None):
 
         base.DualConditionMethod.__init__(self, short_name, long_name, short_desc, long_desc, ctrldata, expdata, annotation_path, output_file, normalization=normalization, replicates=replicates, LOESS=LOESS, NTerminus=NTerminus, CTerminus=CTerminus, wxobj=wxobj)
 
@@ -220,7 +224,8 @@ class ResamplingMethod(base.DualConditionMethod):
         self.doHistogram = doHistogram
         self.includeZeros = includeZeros
         self.pseudocount = pseudocount
-        
+        self.ctrl_lib_str = ctrl_lib_str
+        self.exp_lib_str = exp_lib_str 
 
 
     @classmethod
@@ -252,10 +257,14 @@ class ResamplingMethod(base.DualConditionMethod):
 
         includeZeros = wxobj.resamplingZeroCheckBox.GetValue()
         pseudocount = float(wxobj.resamplingPseudocountText.GetValue())
+        LOESS = wxobj.resamplingLoessCheck.GetValue()
 
+        # Global Parameters
         NTerminus = float(wxobj.globalNTerminusText.GetValue())
         CTerminus = float(wxobj.globalCTerminusText.GetValue())
-        LOESS = wxobj.resamplingLoessCheck.GetValue()
+        ctrl_lib_str = wxobj.ctrlLibText.GetValue()
+        exp_lib_str = wxobj.expLibText.GetValue()
+
 
         #Get output path
         defaultFileName = "resampling_output_s%d_pc%1.2f" % (samples, pseudocount)
@@ -283,7 +292,9 @@ class ResamplingMethod(base.DualConditionMethod):
                 LOESS,
                 ignoreCodon,
                 NTerminus,
-                CTerminus, wxobj)
+                CTerminus, 
+                ctrl_lib_str,
+                exp_lib_str, wxobj)
 
     @classmethod
     def fromargs(self, rawargs):
@@ -301,14 +312,20 @@ class ResamplingMethod(base.DualConditionMethod):
         adaptive = kwargs.get("a", False)
         doHistogram = kwargs.get("h", False)
         replicates = kwargs.get("r", "Sum")
-        includeZeros = kwargs.get("iz", False)
+        excludeZeros = kwargs.get("ez", False)
+        includeZeros = not excludeZeros
         pseudocount = float(kwargs.get("pc", 0.00))
-    
+
+        self.Z = False
+        if "Z" in kwargs: self.Z = True    
         
         LOESS = kwargs.get("l", False)
         ignoreCodon = True
+    
         NTerminus = float(kwargs.get("iN", 0.00))
         CTerminus = float(kwargs.get("iC", 0.00))
+        ctrl_lib_str = kwargs.get("-ctrl_lib", "")
+        exp_lib_str = kwargs.get("-exp_lib", "")
 
         return self(ctrldata,
                 expdata,
@@ -324,9 +341,9 @@ class ResamplingMethod(base.DualConditionMethod):
                 LOESS,
                 ignoreCodon,
                 NTerminus,
-                CTerminus)
-
-
+                CTerminus,
+                ctrl_lib_str,
+                exp_lib_str) # should add Z
 
     def Run(self):
 
@@ -376,7 +393,27 @@ class ResamplingMethod(base.DualConditionMethod):
 
         G = tnseq_tools.Genes(self.ctrldata + self.expdata, self.annotation_path, ignoreCodon=self.ignoreCodon, nterm=self.NTerminus, cterm=self.CTerminus, data=data, position=position)
 
-        #G = tnseq_tools.Genes(self.ctrldata+self.expdata, self.annotation_path, norm=self.normalization, ignoreCodon=self.ignoreCodon, nterm=self.NTerminus, cterm=self.CTerminus)
+
+
+        doLibraryResampling = False
+        # If library string not empty
+        if self.ctrl_lib_str or self.exp_lib_str:
+            letters_ctrl = set(self.ctrl_lib_str)
+            letters_exp = set(self.exp_lib_str)
+
+            # Check if using exactly 1 letters; i.e. no different libraries
+            if len(letters_ctrl) == 1 and letters_exp==1:
+                pass
+            # If using more than one letter, then check no differences in set
+            else:
+                lib_diff = letters_ctrl ^ letters_exp
+                # Check that their differences
+                if not lib_diff:
+                    doLibraryResampling = True
+                else:
+                    transit_tools.transit_error("Error: Library Strings (Ctrl = %s, Exp = %s) do not use the same letters. Make sure every letter / library is represented in both Control and Experimental Conditions. Proceeding with resampling assuming all datasets belong to the same library." % (self.ctrl_lib_str, self.exp_lib_str))
+                    self.ctrl_lib_str = ""
+                    self.exp_lib_str = "" 
 
 
         #Resampling
@@ -398,9 +435,12 @@ class ResamplingMethod(base.DualConditionMethod):
 
                 data1 = gene.reads[:Kctrl,ii].flatten()+self.pseudocount
                 data2 = gene.reads[Kctrl:,ii].flatten()+self.pseudocount
-                
-                (test_obs, mean1, mean2, log2FC, pval_ltail, pval_utail,  pval_2tail, testlist) =  stat_tools.resampling(data1, data2, S=self.samples, testFunc=stat_tools.F_mean_diff_flat, adaptive=self.adaptive)
-
+               
+                if doLibraryResampling:
+                    (test_obs, mean1, mean2, log2FC, pval_ltail, pval_utail,  pval_2tail, testlist) =  stat_tools.resampling(data1, data2, S=self.samples, testFunc=stat_tools.F_mean_diff_dict, permFunc=stat_tools.F_shuffle_dict_libraries, adaptive=self.adaptive, lib_str1=self.ctrl_lib_str, lib_str2=self.exp_lib_str)
+                else:
+                    (test_obs, mean1, mean2, log2FC, pval_ltail, pval_utail,  pval_2tail, testlist) =  stat_tools.resampling(data1, data2, S=self.samples, testFunc=stat_tools.F_mean_diff_flat, permFunc=stat_tools.F_shuffle_flat, adaptive=self.adaptive, lib_str1=self.ctrl_lib_str, lib_str2=self.exp_lib_str)
+ 
 
             if self.doHistogram:
                 import matplotlib.pyplot as plt
@@ -435,7 +475,6 @@ class ResamplingMethod(base.DualConditionMethod):
         data.sort() 
         qval = stat_tools.BH_fdr_correction([row[-1] for row in data])
        
- 
         self.output.write("#Resampling\n")
         if self.wxobj:
             members = sorted([attr for attr in dir(self) if not callable(getattr(self,attr)) and not attr.startswith("__")])
@@ -449,11 +488,21 @@ class ResamplingMethod(base.DualConditionMethod):
         self.output.write("#Experimental Data: %s\n" % (",".join(self.expdata).encode('utf-8'))) 
         self.output.write("#Annotation path: %s\n" % (self.annotation_path.encode('utf-8')))
         self.output.write("#Time: %s\n" % (time.time() - start_time))
+        #Z = True # include Z-score column in resampling output? 
+        global columns # consider redefining columns above (for GUI)
+        if self.Z==True: columns = ["Orf","Name","Desc","Sites","Mean Ctrl","Mean Exp","log2FC", "Sum Ctrl", "Sum Exp", "Delta Mean","p-value","Z-score","Adj. p-value"]
         self.output.write("#%s\n" % "\t".join(columns))
 
         for i,row in enumerate(data):
             (orf, name, desc, n, mean1, mean2, sum1, sum2, test_obs, log2FC, pval_2tail) = row
-            self.output.write("%s\t%s\t%s\t%d\t%1.1f\t%1.1f\t%1.2f\t%1.1f\t%1.2f\t%1.1f\t%1.5f\t%1.5f\n" % (orf, name, desc, n, mean1, mean2, log2FC, sum1, sum2, test_obs, pval_2tail, qval[i]))
+            if self.Z==True:
+              p = pval_2tail/2 # convert from 2-sided back to 1-sided
+              if p==0: p = 1e-5 # or 1 level deeper the num of iterations of resampling, which is 1e-4=1/10000, by default
+              if p==1: p = 1-1e-5
+              z = scipy.stats.norm.ppf(p)
+              if log2FC>0: z *= -1
+              self.output.write("%s\t%s\t%s\t%d\t%1.1f\t%1.1f\t%1.2f\t%1.1f\t%1.2f\t%1.1f\t%1.5f\t%0.2f\t%1.5f\n" % (orf, name, desc, n, mean1, mean2, log2FC, sum1, sum2, test_obs, pval_2tail, z, qval[i]))
+            else: self.output.write("%s\t%s\t%s\t%d\t%1.1f\t%1.1f\t%1.2f\t%1.1f\t%1.2f\t%1.1f\t%1.5f\t%1.5f\n" % (orf, name, desc, n, mean1, mean2, log2FC, sum1, sum2, test_obs, pval_2tail, qval[i]))
         self.output.close()
 
         self.transit_message("Adding File: %s" % (self.output.name))
@@ -462,6 +511,7 @@ class ResamplingMethod(base.DualConditionMethod):
         self.transit_message("Finished resampling Method") 
 
 
+
     @classmethod
     def usage_string(self):
         return """python %s resampling <comma-separated .wig control files> <comma-separated .wig experimental files> <annotation .prot_table or GFF3> <output file> [Optional Arguments]
@@ -471,11 +521,21 @@ class ResamplingMethod(base.DualConditionMethod):
         -n <string>     :=  Normalization method. Default: -n TTR
         -h              :=  Output histogram of the permutations for each gene. Default: Turned Off.
         -a              :=  Perform adaptive resampling. Default: Turned Off.
-        -iz             :=  Include rows with zero accross conditions.
+        -ez             :=  Exclude rows with zero accross conditions. Default: Turned off 
+                            (i.e. include rows with zeros).
         -pc             :=  Pseudocounts to be added at each site.
-        -l              :=  Perform LOESS Correction; Helps remove possible genomic position bias. Default: Turned Off.
+        -l              :=  Perform LOESS Correction; Helps remove possible genomic position bias.
+                            Default: Turned Off.
         -iN <float>     :=  Ignore TAs occuring at given fraction of the N terminus. Default: -iN 0.0
         -iC <float>     :=  Ignore TAs occuring at given fraction of the C terminus. Default: -iC 0.0
+        --ctrl_lib      :=  String of letters representing library of control files in order
+                            e.g. 'AABB'. Default empty. Letters used must also be used in --exp_lib
+                            If non-empty, resampling will limit permutations to within-libraries.
+
+        --exp_lib       :=  String of letters representing library of experimental files in order
+                            e.g. 'ABAB'. Default empty. Letters used must also be used in --ctrl_lib
+                            If non-empty, resampling will limit permutations to within-libraries.
+
         """ % (sys.argv[0])
 
 
