@@ -1,20 +1,25 @@
 import unittest
 import os
 
-ctrl_rep1 = "../src/pytransit/data/glycerol_H37Rv_rep1.wig"
-ctrl_rep2 = "../src/pytransit/data/glycerol_H37Rv_rep2.wig"
+basedir = os.path.dirname(__file__)
+ctrl_rep1 = basedir + "/../src/pytransit/data/glycerol_H37Rv_rep1.wig"
+ctrl_rep2 = basedir + "/../src/pytransit/data/glycerol_H37Rv_rep2.wig"
 ctrl_data_txt = ",".join([ctrl_rep1, ctrl_rep2])
+print(ctrl_data_txt)
 
-exp_rep1 = "../src/pytransit/data/cholesterol_H37Rv_rep1.wig"
-exp_rep2 = "../src/pytransit/data/cholesterol_H37Rv_rep2.wig"
-exp_rep3 = "../src/pytransit/data/cholesterol_H37Rv_rep3.wig"
+combined_wig = basedir + "/../src/pytransit/data/cholesterol_glycerol_combined.dat"
+samples_metadata = basedir + "/../src/pytransit/data/samples_metadata_cg.txt"
+
+exp_rep1 = basedir + "/../src/pytransit/data/cholesterol_H37Rv_rep1.wig"
+exp_rep2 = basedir + "/../src/pytransit/data/cholesterol_H37Rv_rep2.wig"
+exp_rep3 = basedir + "/../src/pytransit/data/cholesterol_H37Rv_rep3.wig"
 exp_data_txt = ",".join([exp_rep1, exp_rep2, exp_rep3])
 
 all_data_list = [ctrl_rep1, ctrl_rep2, exp_rep1, exp_rep2, exp_rep3]
 
-annotation = "../src/pytransit/genomes/H37Rv.prot_table"
-small_annotation = "test.prot_table" 
-output = "testoutput.txt"
+annotation = basedir + "/../src/pytransit/genomes/H37Rv.prot_table"
+small_annotation = basedir + "/test.prot_table"
+output = basedir + "/testoutput.txt"
 
 
 class TransitTestCase(unittest.TestCase):
@@ -23,7 +28,7 @@ class TransitTestCase(unittest.TestCase):
 
         # Print header
         self.header()
-        
+
         # Check if there were output files and remove them
         if os.path.exists(output):
             print "Removing output file..."
